define(
//begin v1.x content
({
	insertTableTitle: "Vložit tabulku",
	modifyTableTitle: "Upravit tabulku",
	rows: "Řádky:",
	columns: "Sloupce:",
	align: "Zarovnat:",
	cellPadding: "Okraj buňky:",
	cellSpacing: "Odstup buněk:",
	tableWidth: "Šířka tabulky:",
	backgroundColor: "Barva pozadí:",
	borderColor: "Barva ohraničení:",
	borderThickness: "TloušťkaOhraničení",
	percent: "procent",
	pixels: "pixelů",
	"default": "výchozí",
	left: "vlevo",
	center: "střed",
	right: "vpravo",
	buttonSet: "Nastavit", // translated elsewhere?
	buttonInsert: "Vložit",
	buttonCancel: "Storno",

	selectTableLabel: "Vybrat tabulku",
	insertTableRowBeforeLabel: "Přidat řádek před",
	insertTableRowAfterLabel: "Přidat řádek za",
	insertTableColumnBeforeLabel: "Přidat sloupec před",
	insertTableColumnAfterLabel: "Přidat sloupec za",
	deleteTableRowLabel: "Odstranit řádek",
	deleteTableColumnLabel: "Odstranit sloupec"
})
//end v1.x content
);
